@@ -226,8 +226,6 @@ class SaiDataset(Base):
         "scarf": 12,
         "vest": 13,
         "shoe": 14,
-        # this shouldn't exist anymore since it's now labeled as "headwear" in the body segmentation
-        "hat": 15,
     }
     """
     Default clothing segmentation mapping
