@@ -64,6 +64,7 @@ def _modality_files(modality: Modality) -> List[_Extension]:
         Modality.HAIR: [_Extension.INFO],
         Modality.FACIAL_HAIR: [_Extension.INFO],
         Modality.EXPRESSION: [_Extension.INFO],
+        Modality.GESTURE: [_Extension.INFO],
         Modality.GAZE: [_Extension.INFO],
         Modality.GAZE_TARGET: [_Extension.INFO],
         Modality.HEAD_TURN: [_Extension.INFO],
@@ -336,6 +337,13 @@ class _ItemLoaderV1(_ItemLoader):
             expression = {"human_1": expression}
             return expression
 
+        if modality == Modality.GESTURE:
+            gesture = info.get("gesture", None)
+            if gesture is None:
+                return None
+            gesture_name = gesture["name"]
+            return gesture_name
+
         if modality == Modality.GAZE:
             gaze = {
                 "right": info["gaze_values"]["eye_right"]["gaze_vector"],
