@@ -215,11 +215,18 @@ class Modality(Enum):
             ...
         }
     """
+    GESTURE = auto()
+    """
+    Name of the gesture.
+
+    **Type**: str
+    """
     GAZE = auto()
     """
     Gaze direction in camera space.
     
     **Format**::
+
         {
             instance_id: {
                 'horizontal_angle': ndarray[float64] **Shape**: `(3,)`.
@@ -233,6 +240,7 @@ class Modality(Enum):
     The target that the gaze direction points to.
 
     **Format**::
+
         {
             instance_id: str
         }
@@ -242,6 +250,7 @@ class Modality(Enum):
     The direction that the head is turned, relative to the body, provided in degrees.
 
     **Format**::
+
         {
             "roll": int,
             "pitch": int,
